@@ -5,21 +5,15 @@ from typing import Type, List, TypeVar
 
 from pytconf.extended_enum import str_to_enum_value, ExtendedEnum
 
-EnumSubsetType = TypeVar('EnumSubsetType', bound='EnumSubset')
+EnumSubsetType = TypeVar("EnumSubsetType", bound="EnumSubset")
 
 
 class EnumSubset:
     @classmethod
     def from_enum_all(cls, e: Type[ExtendedEnum]) -> EnumSubsetType:
-        return EnumSubset(
-            enum_type=e,
-            list_of_values=e.get_list_of_all_values(),
-        )
+        return EnumSubset(enum_type=e, list_of_values=e.get_list_of_all_values(),)
 
-    def __init__(
-            self,
-            enum_type: Type[Enum],
-            list_of_values: List[Type[Enum]]) -> None:
+    def __init__(self, enum_type: Type[Enum], list_of_values: List[Type[Enum]]) -> None:
         self.enum_type = enum_type
         # TODO: this should actually be an ordered set
         self.selected = OrderedDict()
@@ -27,8 +21,9 @@ class EnumSubset:
             self.add(value)
 
     def add(self, enum_value):
-        assert enum_value in enum_value.__class__.__members__.values(),\
-            "bad value {}".format(enum_value)
+        assert (
+            enum_value in enum_value.__class__.__members__.values()
+        ), "bad value {}".format(enum_value)
         self.selected[enum_value] = None
 
     def delete(self, enum_value):
@@ -50,7 +45,7 @@ class EnumSubset:
     @classmethod
     def from_string(cls, e: Type[Enum], s: str) -> EnumSubsetType:
         r = EnumSubset(enum_type=e, list_of_values=[])
-        for name in s.split(','):
+        for name in s.split(","):
             v = str_to_enum_value(s=name, e=e)
             r.add(v)
         return r
